<?php

namespace VerillaGangWp;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Conversions_Table extends \WP_List_Table {

	private static string $conversion_table = 'verilla_conversions';

	/**
	 * Prepare the items for the table to process
	 *
	 * @return Void
	 */
	public function prepare_items() {
		global $wpdb;

		$table = $wpdb->prefix . self::$conversion_table;
		$where = [];

		if ( !empty($_GET['date']) ) {
			if ( !empty($_GET['date']['from']) ) {
				$from = date( 'Y-m-d H:i:s', strtotime( $_GET['date']['from'] ) );
				$where[] = "created_at >= '{$from}'";
			}

			if ( !empty($_GET['date']['to']) ) {
				$to = date( 'Y-m-d H:i:s', strtotime( $_GET['date']['to'] ) );
				$where[] = "created_at <= '{$to}'";
			}
		}

		$filters = empty($where) ? '' : 'WHERE ' . implode( ' AND ', $where );
		$data = (array) $wpdb->get_results( "SELECT * FROM {$table} {$filters}", ARRAY_A );

		$columns  = $this->get_columns();
		$hidden   = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();

		usort( $data, array( &$this, 'sort_data' ) );

		$per_page     = 25;
		$current_page = $this->get_pagenum();
		$total_items  = count( $data );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page'    => $per_page
		) );

		$data = array_slice( $data, ( ( $current_page - 1 ) * $per_page ), $per_page );

		$this->_column_headers = array( $columns, $hidden, $sortable );
		$this->items           = $data;
	}

	/**
	 * Override the parent columns method. Defines the columns to use in your listing table
	 *
	 * @return Array
	 */
	public function get_columns() {
		return array(
			'id'          => 'ID',
			'click_id'    => 'Click ID',
			'wc_order_id' => 'WC Order ID',
			'amount'      => 'Total',
			'currency'    => 'Currency',
			'created_at'  => 'Created At',
		);
	}

	/**
	 * Define which columns are hidden
	 *
	 * @return Array
	 */
	public function get_hidden_columns() {
		return array();
	}

	/**
	 * Define the sortable columns
	 *
	 * @return Array
	 */
	public function get_sortable_columns() {
		return array( 'id' => array( 'id', false ) );
	}

	/**
	 * Define what data to show on each column of the table
	 *
	 * @param Array $item Data
	 * @param String $column_name - Current column name
	 *
	 * @return Mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'id':
			case 'click_id':
			case 'wc_order_id':
			case 'amount':
			case 'currency':
			case 'created_at':
				return $item[ $column_name ];

			default:
				return print_r( $item, true );
		}
	}

	/**
	 * Allows you to sort the data by the variables set in the $_GET
	 *
	 * @return Mixed
	 */
	private function sort_data( $a, $b ) {
		// Set defaults
		$orderby = 'id';
		$order   = 'asc';

		// If orderby is set, use this as the sort column
		if ( ! empty( $_GET['orderby'] ) ) {
			$orderby = $_GET['orderby'];
		}

		// If order is set use this as the order
		if ( ! empty( $_GET['order'] ) ) {
			$order = $_GET['order'];
		}

		// If order by anything non-numeric
		if ( 'created_at' == $orderby || 'click_id' == $orderby || 'currency' == $orderby ) {
			$result = strcmp( $a[ $orderby ], $b[ $orderby ] );
		} else {
			$result = $a[ $orderby ] - $b[ $orderby ];
		}

		if ( 'asc' == $order ) {
			return $result;
		}

		return - $result;
	}

	protected function months_dropdown( $post_type ) {
		?>
		<label style="display: inline-block; font-weight: bold;">Filter By Date:</label>

		<input type="datetime-local" name="date[from]" value="<?php echo @$_GET['date']['from']; ?>" />
		<input type="datetime-local" name="date[to]" value="<?php echo @$_GET['date']['to']; ?>" />

		<input type="submit" name="filter_action" id="post-query-submit" class="button" value="Filter" />
		<?php
	}

	protected function extra_tablenav( $which ) {
		if ( 'top' != $which ) return;
		$this->months_dropdown( self::$conversion_table );
	}
}