<?php

namespace VerillaGangWp;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Database {
	private static string $conversion_table = 'verilla_conversions';

	public static function create_conversions_table() {
		global $wpdb;

		$table_name      = $wpdb->prefix . self::$conversion_table;
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE `{$table_name}` (
		 `id` BIGINT NOT NULL AUTO_INCREMENT,
		 `click_id` TEXT NOT NULL,
		 `wc_order_id` BIGINT NOT NULL,
		 `wc_order` TEXT NOT NULL,
		 `amount` DECIMAL(10,2) NOT NULL,
		 `currency` VARCHAR(20) NOT NULL,
		 `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
		 `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
		 PRIMARY KEY (id)
		 ) {$charset_collate};";

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';

		maybe_create_table( $table_name, $sql );
	}

    public static function drop_conversions_table() {
        global $wpdb;

        $table_name = $wpdb->prefix . self::$conversion_table;

        $wpdb->query( "DROP TABLE IF EXISTS '{$table_name}'" );
    }

	public static function insert_new_order_conversion( $click_id, $order ) {
		global $wpdb;

		$table = $wpdb->prefix . self::$conversion_table;

		$currency     = $order->currency;
		$total_amount = $order->total;
		$order_id     = $order->id;

		$order_items = array();

		foreach ( $order->get_items() as $product ) {
			$order_items[] = array(
				'id'           => $product['product_id'],
				'name'         => $product['name'],
				'variation_id' => $product['variation_id'],
				'quantity'     => $product['quantity'],
				'total'        => $product['total'],
			);
		}

		$wpdb->insert( $table, array(
			'click_id'    => $click_id,
			'wc_order_id' => $order_id,
			'wc_order'    => json_encode( $order_items ),
			'amount'      => $total_amount,
			'currency'    => $currency,
		) );
	}

	public static function get_conversion_table_name() {
		return self::$conversion_table;
	}
}