<?php

namespace VerillaGangWp;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Events {
	private static string $url = 'https://postback.verillagang.com/woocommerce.php';

	public static function install() {
		if ( ! class_exists( 'WooCommerce' ) ) return;

		$products = array();
		$args = array(
			'status' => 'publish',
			'limit'  => -1,
		);

		foreach ( wc_get_products( $args ) as $product ) {
			$products += self::product_data( $product );
		}

		self::send_event( array(
			'request'    => 'install',
			'products'   => $products,
		) );
	}

	public static function uninstall() {
		self::send_event( array(
			'request'    => 'deleteStore',
		) );
	}

	public static function add_product( $new_status, $old_status, $post ) {
		if ( 'product' !== $post->post_type ) return;
		if ( 'publish' !== $new_status ) return;
		if ( 'publish' === $old_status ) return;

		$product = wc_get_product( $post->ID );
		if ( empty($product) ) return;

		self::send_event( array(
			'request'  => 'addProduct',
			'products' => self::product_data( $product ),
		) );
	}

	public static function update_product( $id ) {
		$product = wc_get_product( $id );

		if ( empty($product) ) return;

		self::send_event( array(
			'request'  => 'editProduct',
			'products' => self::product_data( $product ),
		) );
	}

	public static function delete_product( $id ) {
		$product = wc_get_product( $id );

		if ( empty($product) ) return;

		self::send_event( array(
			'request'  => 'deleteProduct',
			'products' => self::product_data( $product ),
		) );
	}

	public static function product_data( $product ) {
		$products = [];

		$id   = $product->get_id();
		$type = $product->get_type();

		$base = array(
			'product_id'        => $id,
			'title'             => $product->get_title(),
			'description'       => $product->get_description(),
			'category_ids'      => $product->get_category_ids(),
			'category_name'     => get_the_terms( $id, 'product_cat' ),	
			'gallery_image_ids' => $product->get_gallery_image_ids(),
			'type'              => $type,
			'permalink'         => get_permalink($id),
		);

		if ( $type == 'variable' ) {
			foreach ( $product->get_available_variations() as $variation ) {
				$wc_variation = new \WC_Product_variation($variation['variation_id']);

				$products[] = array_merge( $base, array(
					'variation_id'   => $variation['variation_id'],
					'price'          => $variation['display_price'],
					'regular_price'  => $variation['display_regular_price'],
					'sale_price'     => $variation['display_price'],
					'sku'            => $variation['sku'],
					'stock_quantity' => $wc_variation->get_stock_quantity(),
					'attributes'     => $variation['attributes'],
				) );
			}
		} else {
			$products[] = array_merge( $base, array(
				'variation_id'   => $id,
				'price'          => $product->get_price(),
				'regular_price'  => $product->get_regular_price(),
				'sale_price'     => $product->get_sale_price(),
				'sku'            => $product->get_sku(),
				'stock_quantity' => $product->get_stock_quantity(),
				'attributes'     => $product->get_attributes(),
			) );
		}

		return $products;
	}

	public static function send_event($payload) {
		if ( empty($payload) ) return;

		$payload['token']      = verilla_gang_get_token();
		$payload['store_name'] = get_bloginfo( 'name' );
		$payload['store_url']  = get_bloginfo( 'url' );

		$response = wp_remote_post( self::$url, array(
			'method' => 'POST',
			'body'   => json_encode($payload),
		) );

		if ( is_wp_error( $response ) ) {
			$logger = new Logger( 'verilla_logger' );
			$logger->pushHandler( new StreamHandler( __DIR__ . '/logs/app_error.log', Logger::ERROR ) );
			$logger->error( $response->get_error_message() );
		}
	}
}