<?php

namespace VerillaGangWp;

use GuzzleHttp\Client;
use GuzzleHttp\Exception\BadResponseException;
use Monolog\Handler\StreamHandler;
use Monolog\Logger;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Postback {
	private static string $postback_url = 'https://postback.verillagang.com/postback.php';

	public static function fire_postback( $click_id, $order_details ) {
		$products = array();

		foreach ( $order_details->get_items() as $product ) {
			$products[] = array(
				'product_id'   => $product['product_id'],
				'name'         => $product['name'],
				'variation_id' => $product['variation_id'],
				'quantity'     => $product['quantity'],
				'total'        => $product['total'],
			);
		}

        $data = $order_details->get_data();
        $details = array(
            'order_id'	  => $data['id'],
            'customer_id' => $data['customer_id'],
            'shipping'	  => $data['shipping_total'],
            'total_tax'   => $data['total_tax'],
            'currency'	  => $data['currency'],
        );

		$parameters = array(
			'json' => array(
				'click_id'       => $click_id,
				'transaction_id' => $order_details->id,
				'sale_amount'    => $order_details->total,
				'products'       => $products,
                'order_details'  => $details,
            ),
		);

		try {
			$client   = new Client();
			$response = $client->request( 'POST', self::$postback_url, $parameters );
		} catch ( BadResponseException $exception ) {
			$logger = new Logger( 'verilla_logger' );
			$logger->pushHandler( new StreamHandler( __DIR__ . '/logs/app_error.log', Logger::ERROR ) );
			$logger->error( $exception->getMessage() );
		}
	}
}