<?php

namespace VerillaGangWp;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Updater
{
	private $file;
	private $plugin;
	private $basename;
	private $remote_plugin;
	private $base_url = 'https://wp-plugin.verillagang.com/update/';

	public function __construct( $file )
	{
		$this->file = $file;
		$this->plugin = get_plugin_data( $file );
		$this->basename = plugin_basename( $file );
		$this->remote_plugin = $this->pull_remote_plugin_info();
	}

	public function init()
	{
		add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'modify_transient' ), 10, 1 );
		add_filter( 'plugins_api', array( $this, 'plugin_popup' ), 10, 3 );
		add_filter( 'upgrader_post_install', array( $this, 'after_install' ), 10, 3 );
	}

	private function pull_remote_plugin_info()
	{
		$url = $this->base_url . '?action=get_metadata&slug=' . dirname($this->basename);

		$options = array(
			'timeout' => 10, //seconds
			'headers' => array(
				'Accept' => 'application/json',
			),
		);

		$result = wp_remote_get($url, $options);
		$body = wp_remote_retrieve_body( $result );

		return json_decode( $body );
	}

	private function generate_plugin_transient_object()
	{
		return (object) array(
			'id'           => $this->plugin['TextDomain'],
			'slug'         => $this->plugin['TextDomain'],
			'plugin'       => $this->basename,
			'new_version'  => $this->plugin['Version'],
			'url'          => $this->plugin['PluginURI'],
			'package'      => '',
			'icons'        => array(),
			'banners'      => array(),
			'banners_rtl'  => array(),
			'tested'       => '',
			'requires_php' => '',
		);
	}

	public function modify_transient( $transient )
	{
		if ( property_exists( $transient, 'checked' ) ) {
			$plugin_transient_object = $this->generate_plugin_transient_object();

			$remote_version = $this->remote_plugin->version ?? 0;
			$local_version = $this->plugin['Version'];

			$out_of_date = version_compare( $remote_version, $local_version, '>' );

			if ( $out_of_date ) {
				$plugin_transient_object->new_version = $remote_version;
				$plugin_transient_object->package = $this->remote_plugin->download_url;
				$transient->response[ $this->basename ] = $plugin_transient_object;
			} else {
				$transient->no_update[ $this->basename ] = $plugin_transient_object;
			}
		}

		return $transient;
	}

	public function plugin_popup( $result, $action, $args )
	{
		if ( 'plugin_information' != $action ) {
			return false;
		}

		if ( empty( $args->slug ) ) {
			return $result;
		}

		$paths = explode( '/', $this->basename );
		$path = current( $paths );

		if ( $args->slug != $path ) {
			return $result;
		}

		return (object) array(
			'name'              => $this->plugin['Name'],
			'slug'              => $this->basename,
			'version'           => $this->remote_plugin->version ?? $this->plugin["Version"],
			'author'            => $this->plugin['AuthorName'],
			'author_profile'    => $this->plugin['AuthorURI'],
			'last_updated'      => $this->remote_plugin->last_updated ?? null,
			'homepage'          => $this->plugin['PluginURI'],
			'short_description' => $this->plugin['Description'],
			'sections'          => array(
				'Description' => $this->plugin['Description'],
			),
			'download_link'     => $this->remote_plugin->download_url ?? null,
		);
	}

	public function after_install( $response, $hook_extra, $result )
	{
		global $wp_filesystem;

		$directory = plugin_dir_path( $this->file );
		$wp_filesystem->move( $result['destination'], $directory );
		$result['destination'] = $directory;

		if ( $this->active ) {
			activate_plugin( $this->basename );
		}

		return $result;
	}
}
