<?php

/**
 * Plugin Name: Verilla Gang WP
 * Plugin URI: https://verillagang.com/
 * Description: Verilla Gang Creators plugin to notify the platform for clicks and sales.
 * Version: 0.0.3
 * Author: VerillaGgang
 * Requires PHP: 8.0
 * License: GPL2
 */

use VerillaGangWp\Updater;
use VerillaGangWp\Helpers;
use VerillaGangWp\Menu;
use VerillaGangWp\Order;
use VerillaGangWp\Database;
use VerillaGangWp\Events;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

spl_autoload_register(function ($class_name) {
    $names = explode( '\\', $class_name );

    if ( count($names) < 2 || 'VerillaGangWp' != $names[0] ) {
        return;
    }

    $name = str_replace( '_', '-',  strtolower($names[1]) );
    include __DIR__ . "/src/class-{$name}.php";
});

function verilla_gang_get_token() {
    $key = 'vgwp_token';
    $value = get_option( 'vgwp_token' );

    if ( $value ) return $value;

    $time = time();
    $hash = md5( $time );
    $token = "{$time}:{$hash}";

    update_option( 'vgwp_token', $token );

    return $token;
}

function verilla_gang_register_plugin() {
    Database::create_conversions_table();
    Events::install();
}

function verilla_gang_unregister_plugin() {
    Database::drop_conversions_table();
    Events::uninstall();

    delete_option( 'vgwp_token' );
}

function verilla_gang_init_plugin() {
    Helpers::initiate_click_id();
    $updater = new Updater( __FILE__ );
    $updater->init();
}

function verilla_gang_wc_payment_complete( $order_id ) {
    Order::new_order( $order_id );
}

function verilla_gang_add_stylesheet_to_admin() {
    $url = plugins_url( '/src/resources/assets/css/table.css', __FILE__ );
    wp_enqueue_style( 'verilla-gang', $url );
}

function verilla_gang_create_menu() {
    $menu = new Menu();
    $menu->create_menu();
}

function verilla_gang_plugins_loaded() {
    include_once ABSPATH . 'wp-admin/includes/plugin.php';

    if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
        return;
    }

    require_once __DIR__ . '/vendor/autoload.php';

    if ( ! isset( $_SESSION ) ) {
        session_start();
    }

    add_action( 'init', 'verilla_gang_init_plugin' );
    add_action( 'woocommerce_payment_complete', 'verilla_gang_wc_payment_complete' );
    add_action( 'admin_enqueue_scripts', 'verilla_gang_add_stylesheet_to_admin' );

    add_action( 'transition_post_status', array( 'VerillaGangWp\Events', 'add_product' ), 10, 3 );
    add_action( 'woocommerce_update_product', array( 'VerillaGangWp\Events', 'update_product' ) );
    add_action( 'before_delete_post', array( 'VerillaGangWp\Events', 'delete_product' ) );

    if ( is_admin() ) {
        add_action( 'admin_menu', 'verilla_gang_create_menu' );
    }
}

add_action( 'plugins_loaded', 'verilla_gang_plugins_loaded' );

register_activation_hook( __FILE__, 'verilla_gang_register_plugin' );
register_deactivation_hook( __FILE__, 'verilla_gang_unregister_plugin' );
register_uninstall_hook( __FILE__, 'verilla_gang_unregister_plugin' );
